@@ -10,6 +10,7 @@
 #include "modeltest.h"
 
 #include <QTest>
+#include <qabstracteventdispatcher.h>
 
 /*!
     Connect to all of the models signals.  Whenever anything happens recheck everything.
@@ -24,7 +25,7 @@ ModelTest::ModelTest(QAbstractItemModel *_model, Mode testType, QObject *parent)
     if (pedantic) {
         refreshStatus();
         // This is almost certainly not needed.
-        //         connect(QAbstractEventDispatcher::instance(), SIGNAL(awake()), SLOT(ensureSteady()));
+        //         connect(QAbstractEventDispatcher::instance(), &QAbstractEventDispatcher::awake, this, &ModelTest::ensureSteady);
     }
 }
 
@@ -43,37 +44,34 @@ void ModelTest::init()
         qFatal("%s: model must not be null", Q_FUNC_INFO);
     }
 
-    connect(model, SIGNAL(columnsAboutToBeInserted(QModelIndex, int, int)), this, SLOT(runAllTests()));
-    connect(model, SIGNAL(columnsAboutToBeRemoved(QModelIndex, int, int)), this, SLOT(runAllTests()));
-    connect(model, SIGNAL(columnsInserted(QModelIndex, int, int)), this, SLOT(runAllTests()));
-    connect(model, SIGNAL(columnsRemoved(QModelIndex, int, int)), this, SLOT(runAllTests()));
-    connect(model, SIGNAL(dataChanged(QModelIndex, QModelIndex)), this, SLOT(runAllTests()));
-    connect(model, SIGNAL(headerDataChanged(Qt::Orientation, int, int)), this, SLOT(runAllTests()));
-    connect(model, SIGNAL(layoutAboutToBeChanged()), this, SLOT(runAllTests()));
-    connect(model, SIGNAL(layoutChanged()), this, SLOT(runAllTests()));
-    connect(model, SIGNAL(modelReset()), this, SLOT(runAllTests()));
-    connect(model, SIGNAL(modelAboutToBeReset()), this, SLOT(modelAboutToBeReset()));
-    connect(model, SIGNAL(modelReset()), this, SLOT(modelReset()));
-    connect(model, SIGNAL(rowsAboutToBeInserted(QModelIndex, int, int)), this, SLOT(runAllTests()));
-    connect(model, SIGNAL(rowsAboutToBeRemoved(QModelIndex, int, int)), this, SLOT(runAllTests()));
-    connect(model, SIGNAL(rowsInserted(QModelIndex, int, int)), this, SLOT(runAllTests()));
-    connect(model, SIGNAL(rowsRemoved(QModelIndex, int, int)), this, SLOT(runAllTests()));
+    connect(model, &QAbstractItemModel::columnsAboutToBeInserted, this, &ModelTest::runAllTests);
+    connect(model, &QAbstractItemModel::columnsAboutToBeRemoved, this, &ModelTest::runAllTests);
+    connect(model, &QAbstractItemModel::columnsInserted, this, &ModelTest::runAllTests);
+    connect(model, &QAbstractItemModel::columnsRemoved, this, &ModelTest::runAllTests);
+    connect(model, &QAbstractItemModel::dataChanged, this, &ModelTest::runAllTests);
+    connect(model, &QAbstractItemModel::headerDataChanged, this, &ModelTest::runAllTests);
+    connect(model, &QAbstractItemModel::layoutAboutToBeChanged, this, &ModelTest::runAllTests);
+    connect(model, &QAbstractItemModel::layoutChanged, this, &ModelTest::runAllTests);
+    connect(model, &QAbstractItemModel::modelReset, this, &ModelTest::runAllTests);
+    connect(model, &QAbstractItemModel::modelAboutToBeReset, this, &ModelTest::modelAboutToBeReset);
+    connect(model, &QAbstractItemModel::modelReset, this, &ModelTest::modelReset);
+    connect(model, &QAbstractItemModel::rowsAboutToBeInserted, this, &ModelTest::runAllTests);
+    connect(model, &QAbstractItemModel::rowsAboutToBeRemoved, this, &ModelTest::runAllTests);
+    connect(model, &QAbstractItemModel::rowsInserted, this, &ModelTest::runAllTests);
+    connect(model, &QAbstractItemModel::rowsRemoved, this, &ModelTest::runAllTests);
 
     // Special checks for changes
-    connect(model, SIGNAL(layoutAboutToBeChanged()), this, SLOT(layoutAboutToBeChanged()));
-    connect(model, SIGNAL(layoutChanged()), this, SLOT(layoutChanged()));
+    connect(model, &QAbstractItemModel::layoutAboutToBeChanged, this, &ModelTest::layoutAboutToBeChanged);
+    connect(model, &QAbstractItemModel::layoutChanged, this, &ModelTest::layoutChanged);
 
-    connect(model, SIGNAL(rowsAboutToBeInserted(QModelIndex, int, int)), this, SLOT(rowsAboutToBeInserted(QModelIndex, int, int)));
-    connect(model, SIGNAL(rowsAboutToBeRemoved(QModelIndex, int, int)), this, SLOT(rowsAboutToBeRemoved(QModelIndex, int, int)));
-    connect(model, SIGNAL(rowsInserted(QModelIndex, int, int)), this, SLOT(rowsInserted(QModelIndex, int, int)));
-    connect(model, SIGNAL(rowsRemoved(QModelIndex, int, int)), this, SLOT(rowsRemoved(QModelIndex, int, int)));
-    connect(model,
-            SIGNAL(rowsAboutToBeMoved(QModelIndex, int, int, QModelIndex, int)),
-            this,
-            SLOT(rowsAboutToBeMoved(QModelIndex, int, int, QModelIndex, int)));
-    connect(model, SIGNAL(rowsMoved(QModelIndex, int, int, QModelIndex, int)), this, SLOT(rowsMoved(QModelIndex, int, int, QModelIndex, int)));
-    connect(model, SIGNAL(dataChanged(QModelIndex, QModelIndex)), this, SLOT(dataChanged(QModelIndex, QModelIndex)));
-    connect(model, SIGNAL(headerDataChanged(Qt::Orientation, int, int)), this, SLOT(headerDataChanged(Qt::Orientation, int, int)));
+    connect(model, &QAbstractItemModel::rowsAboutToBeInserted, this, &ModelTest::rowsAboutToBeInserted);
+    connect(model, &QAbstractItemModel::rowsAboutToBeRemoved, this, &ModelTest::rowsAboutToBeRemoved);
+    connect(model, &QAbstractItemModel::rowsInserted, this, &ModelTest::rowsInserted);
+    connect(model, &QAbstractItemModel::rowsRemoved, this, &ModelTest::rowsRemoved);
+    connect(model, &QAbstractItemModel::rowsAboutToBeMoved, this, &ModelTest::rowsAboutToBeMoved);
+    connect(model, &QAbstractItemModel::rowsMoved, this, &ModelTest::rowsMoved);
+    connect(model, &QAbstractItemModel::dataChanged, this, &ModelTest::dataChanged);
+    connect(model, &QAbstractItemModel::headerDataChanged, this, &ModelTest::headerDataChanged);
 
     runAllTests();
 }
